import { CreateUserDTO } from '@application/dtos/user/create-user'
import { CryptographyAdapter } from '@domain/adapters/cryptography'
import { ExceptionsAdapter } from '@domain/adapters/exceptions'
import { User } from '@domain/entities/user'
import { UserRepository } from '@domain/repositories/user'
import { Injectable } from '@nestjs/common'

@Injectable()
export class CreateUserUseCase {
  constructor(
    private readonly userRepository: UserRepository,
    private readonly exceptionAdapter: ExceptionsAdapter,
    private readonly hashAdapter: CryptographyAdapter,
  ) {}

  async execute(user: CreateUserDTO): Promise<User | void> {
    const findUser = await this.userRepository.findUserByEmail(user.email)

    if (findUser) {
      return this.exceptionAdapter.badRequest({
        message: 'Already exist user with this email',
      })
    }

    const hashedPassword = await this.hashAdapter.generateHash(user.password)

    const { name, email, phone, city, state, language, role } = user

    const newUser = new User({
      name,
      email,
      password: hashedPassword,
      phone,
      city,
      state,
      language,
      role,
      created_at: new Date(),
      updated_at: new Date(),
      deleted_at: null,
    })
    return await this.userRepository.createUser(newUser)
  }
}
