import { ExceptionsAdapter } from '@domain/adapters/exceptions'
import { UserRepository } from '@domain/repositories/user'
import { Injectable } from '@nestjs/common'

@Injectable()
export class DeleteUserUseCase {
  constructor(
    private readonly userRepository: UserRepository,
    private readonly exceptionAdapter: ExceptionsAdapter,
  ) {}

  async execute(id: string): Promise<void> {
    const user = await this.userRepository.findUserById(id)

    if (!user) {
      return this.exceptionAdapter.notFound({
        message: 'Not found a user with this id',
      })
    }

    await this.userRepository.delete(id)
  }
}
