import { ExceptionsAdapter } from '@domain/adapters/exceptions'
import { User } from '@domain/entities/user'
import { UserRepository } from '@domain/repositories/user'
import { Injectable } from '@nestjs/common'

@Injectable()
export class FindByUserIdUseCase {
  constructor(
    private readonly userRepository: UserRepository,
    private readonly exceptionAdapter: ExceptionsAdapter,
  ) {}

  async execute(id: string): Promise<User | void> {
    const findById = await this.userRepository.findUserById(id)

    if (!findById) {
      return this.exceptionAdapter.notFound({
        message: 'Not found a user with this id',
      })
    }

    return findById
  }
}
