import { UpdateUserDTO } from '@application/dtos/user/update-user'
import { CryptographyAdapter } from '@domain/adapters/cryptography'
import { ExceptionsAdapter } from '@domain/adapters/exceptions'
import { User } from '@domain/entities/user'
import { UserRepository } from '@domain/repositories/user'
import { Injectable } from '@nestjs/common'

@Injectable()
export class UpdateUserUseCase {
  constructor(
    private readonly userRepository: UserRepository,
    private readonly exceptionAdapter: ExceptionsAdapter,
    private readonly hashAdapter: CryptographyAdapter,
  ) {}

  async execute(
    id: string,
    updateUserDto: UpdateUserDTO,
  ): Promise<User | void> {
    const { city, email, language, name, password, phone, state } =
      updateUserDto

    const user = await this.userRepository.findUserById(id)

    if (!user) {
      return this.exceptionAdapter.notFound({
        message: 'Not found a user with this id',
      })
    }

    if (email) {
      const emailAlreadyUse = await this.userRepository.findUserByEmail(email)

      if (emailAlreadyUse) {
        return this.exceptionAdapter.badRequest({
          message: 'This email already use',
        })
      }
    }

    let hashPassword = user.getPassword()
    if (password) {
      hashPassword = await this.hashAdapter.generateHash(password)
    }

    user.setCity(city ?? user.getCity())
    user.setEmail(email ?? user.getEmail())
    user.setLanguage(language ?? user.getLanguage())
    user.setName(name ?? user.getName())
    user.setPassword(hashPassword)
    user.setPhone(phone ?? user.getPhone())
    user.setState(state ?? user.getState())
    user.setUpdatedAt(new Date())

    return await this.userRepository.updateUser(id, user)
  }
}
