import { Module } from '@nestjs/common'
import { UserController } from '@persistence/controllers/user.controller'
import { CryptographyModule } from '../cryptography/cryptography.module'
import { DatabaseModule } from '../database/database.module'
import { ExceptionsModule } from '../exceptions/exceptions.module'
import { CreateUserUseCase } from '@application/use-cases/user/create.use-case'
import { FindAllUserUseCase } from '@application/use-cases/user/find-all.use-case'
import { DeleteUserUseCase } from '@application/use-cases/user/delete-user.use-case'
import { FindByUserIdUseCase } from '@application/use-cases/user/find-by-id.use-case'
import { UpdateUserUseCase } from '@application/use-cases/user/update-user.use-case'

@Module({
  imports: [DatabaseModule, ExceptionsModule, CryptographyModule],
  controllers: [UserController],
  providers: [
    CreateUserUseCase,
    FindAllUserUseCase,
    DeleteUserUseCase,
    FindByUserIdUseCase,
    UpdateUserUseCase,
  ],
})
export class UserModule {}
